@@ -40,12 +40,17 @@ class ChannelStatsSerializer(serializers.ModelSerializer):
             return None
     class Meta:
         model = ChannelStats
-        fields = ['channel', 'type', 'value','model']
+        fields = ['id', 'channel', 'type', 'value','model']
 
 class ChannelSerializer(serializers.ModelSerializer):
-    channelstats = ChannelStatsSerializer(read_only=True,many=True)
+    channelstats_set = ChannelStatsSerializer(read_only=True,many=True)
     model = serializers.SerializerMethodField()
 
+    def restore_object(self, attrs, instance=None):
+        instance = super(ChannelSerializer, self).restore_object(attrs, instance)
+        instance.channelstats = ChannelStats.objects.get({'channel':instance.id}).all
+        return instance
+
     def get_model(self, instance):
         try:
             return instance.__class__.__name__
@@ -54,7 +59,7 @@ class ChannelSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = Channel
-        fields = ['id', 'type', 'channel_index', 'hardware','channelstats','model','keep_statistics']
+        fields = ['id', 'type', 'channel_index', 'hardware','channelstats_set','model','keep_statistics']
 
 
 
