@@ -155,11 +155,27 @@ class HardwareViewSet(viewsets.ModelViewSet):
 
     def getChannels(self, hardware_id):
         channels = Hardware.objects.get(pk=str(hardware_id)).channel_set.all()
-        serialized_channels = ChannelSerializer(channels,many=True).data
-
+        serialized_channels = []
+        for channel in channels:
+            temp_channel = Channel.objects.get(pk=channel.id)
+            serializer = ChannelSerializer(temp_channel)
+            serializer.is_valid()
+            serialized_channels.append(ChannelSerializer(temp_channel).data)
         # if request.accepted_renderer.format == 'html':
+        print('get channels '+ str(hardware_id))
+        print(str(serialized_channels))
         return JsonResponse(serialized_channels, status=200, safe=False)
 
+    # def getChannels(self, hardware_id):
+    #     channels = Hardware.objects.get(pk=str(hardware_id)).channel_set.all()
+    #     for channel in channels:
+    #         channel.channelstat_set.all()
+    #
+    #     serialized_channels = ChannelSerializer(channels,many=True).data
+    #
+    #     # if request.accepted_renderer.format == 'html':
+    #     return JsonResponse(serialized_channels, status=200, safe=False)
+
     def getConfig(self, hardware_id):
         hardware_configs = Hardware.objects.get(pk=str(hardware_id)).hardwareconfig_set.all()
         config = {}
